@@ -11,6 +11,7 @@ import gym
 from gym import error, spaces, utils
 #from gym.utils import seeding
 #import statsmodels
+import statsmodels.api as sm
 import statsmodels.formula.api as smf
 import pandas.util.testing as tm
 from sklearn.linear_model import LogisticRegression
@@ -18,8 +19,8 @@ from sklearn.linear_model import LogisticRegression
 #Gym environment
 
 class DiscreteEnv(gym.Env):
-  def __init__(self, n = 200):
-    self.size = n
+  def __init__(self):
+    self.size = 200
     #get initial values for theta's
     #fit logit model to data
     self.df = pd.DataFrame(dict(
